# 续命仪 life-prolonging

#### 菜鸡程序员拿命换钱，伟大工程师为自己续命。——穆罕默德·道格拉斯·鲁迅
#### 突破舒适区，才能变得更强更健康。——鲁迅

很多地方都在完善中，欢迎提issue。

工程师、科学家、研究员的健康指南。

安装
```shell script
pip install life-prolonging
```

查看帮助
```shell script
lpl -h
```


不知道吃啥、喝啥、健身做啥动作、去哪郊游一个命令告诉你。

目前支持：蔬菜、饮料、健身动作、游戏。

随机列表逐步完善中，列表都是作者优选。

为祖国健康工作五十年——清华大学校长·🇨🇳教育部部长·蒋南翔

身体是革命的本钱——全境守护者·毛泽东

Python 随机生成
